class FileCache:
	def __init__(self, f, compression=False):
		self.compression = compression
		self.f = f
		if compression:
			import zstandard as zstd
			self.cctx = zstd.ZstdCompressor()
			self.reader = self.cctx.read_to_iter(self.f, write_size=8192)
		else:
			self.reader = self.f
		self.next_chunk = b""

	def grow_chunk(self):
		new_chunk = self.reader.__next__()
		if new_chunk is None:
			raise StopIteration()
		self.next_chunk = self.next_chunk + new_chunk

	def read(self, n):
		if self.compression:
			if self.next_chunk is None:
				return None
		else:
			if not self.reader.readable():
				return None
		try:
			if not self.compression:
				rv = self.reader.read(n)
			else:
				while len(self.next_chunk) < n:
					self.grow_chunk()
				rv = self.next_chunk[:n]
				self.next_chunk = self.next_chunk[n:]
			return rv
		except StopIteration:
			rv = self.next_chunk
			self.next_chunk = None
			return rv



# !/usr/bin/env python

import logging

from glacier_rsync.argparser import ArgParser
from glacier_rsync.backup_util import BackupUtil


def main():
	args = ArgParser().get_args()
	logging.getLogger(__name__)
	logging.basicConfig(
		format="%(asctime)s - %(module)s.%(funcName)s:%(lineno)d - %(levelname)s - %(message)s",
		level=getattr(logging, args.log_level, None))

	backup_util = BackupUtil(args)
	backup_util.backup()


if __name__ == "__main__":
	main()



import os

from setuptools import setup, find_packages


def read_file(file_name):
	"""Read file and return its contents."""
	with open(file_name, 'r') as f:
		return f.read()


def read_requirements(file_name):
	"""Read requirements file as a list."""
	print(os.listdir('.'))
	reqs = read_file(file_name).splitlines()
	if not reqs:
		raise RuntimeError(
			"Unable to read requirements from the %s file"
			"That indicates this copy of the source code is incomplete."
			% file_name
		)
	return reqs


setup(
	name='glacier-rsync',
	version='0.3.0',
	url='https://github.com/cagdasbas/glacier-rsync',
	python_requires='>=3.8',
	description='Rsync like utility for backing up files/folders to AWS Glacier',
	long_description=read_file('README.md'),
	long_description_content_type="text/markdown",
	author='Cagdas Bas',
	author_email='cagdasbs@gmail.com',
	packages=find_packages("."),
	include_package_data=True,
	entry_points={
		"console_scripts": [
			"grsync = glacier_rsync.__main__:main",
		]
	},
	install_requires=read_requirements('requirements.txt'),
	extras_require={
		'compression': ["zstandard"]
	},
	classifiers=[
		'Development Status :: 5 - Production/Stable',
		'Intended Audience :: Developers',
		'Natural Language :: English',
		'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
		'Programming Language :: Python',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.8',
	],
)
